#
# spec file
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%global flavor %{nil}
%if "%{flavor}" == "test"
%define psuffix -test
%bcond_without test
%else
%define psuffix %{nil}
%bcond_with test
%endif
%define tarname PyOpenGL
Name:           python-opengl%{psuffix}
Version:        3.1.6
Release:        bp156.2.2
Summary:        OpenGL bindings for Python
License:        BSD-3-Clause
Group:          Development/Libraries/Python
URL:            http://pyopengl.sourceforge.net
Source0:        https://files.pythonhosted.org/packages/source/P/%{tarname}/%{tarname}-%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       Mesa-dri
Recommends:     python-numpy
Recommends:     python-opengl-accelerate
Recommends:     python-tk
Recommends:     tk >= 8.1
Provides:       python-PyOpenGL = %{version}-%{release}
BuildArch:      noarch
%if %{with test}
BuildRequires:  %{python_module Pillow}
BuildRequires:  %{python_module opengl-accelerate}
BuildRequires:  %{python_module psutil}
BuildRequires:  %{python_module pytest-xvfb}
BuildRequires:  %{python_module pytest}
BuildRequires:  Mesa-dri
BuildRequires:  freeglut-devel
BuildRequires:  libdrm-devel
BuildRequires:  libgle-devel
BuildRequires:  python3-numpy
BuildRequires:  swig
BuildRequires:  tk-devel
BuildRequires:  %{python_module pygame if (%python-base without python36-base)}
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(glu)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xcb-glx)
%endif
%python_subpackages

%description
OpenGL bindings for Python including support for GL extensions, GLU,
WGL, GLUT, GLE, and Tk.

%prep
%setup -q -n %{tarname}-%{version}
# remove shebang
sed -e '1d' -i OpenGL/arrays/_buffers.py OpenGL/arrays/buffers.py
# avoid "python-bytecode-inconsistent-mtime" warning
FAKE_TIMESTAMP=$(LC_ALL=C date -u -r OpenGL/__init__.py +%%y%%m%%d%%H%%M)
find . -name '*.py' -exec touch -mat $FAKE_TIMESTAMP {} \;

%build
%python_build

%install
%if !%{with test}
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%endif

%if %{with test}
%check
# don't test anything on python36: all tests need pygame, which is not available
python36_flags="--version"
%pytest ${$python_flags} tests
%endif

%if !%{with test}
%files %{python_files}
%license license.txt
%{python_sitelib}/OpenGL/
%{python_sitelib}/PyOpenGL-%{version}-py%{python_version}.egg-info
%endif

%changelog
* Sat Mar 26 2022 Dirk Müller <dmueller@suse.com>
- update to 3.1.6:
  * python 3.8-3.10 support
* Tue Mar 23 2021 Ben Greiner <code@bnavigator.de>
- Don't test with pygame for python36. Pygame requires NumPy which
  is not available for python36 on TW.
* Thu Apr 30 2020 Benjamin Greiner <code@bnavigator.de>
- Update to 3.1.5
- move to pytest-xvfb for tests
- the runtime requirement of Mesa-dri was not picked up automatically
* Mon Sep  9 2019 Tomáš Chvátal <tchvatal@suse.com>
- Switch to multibuild to avoid buildcycle
* Sun Aug 18 2019 John Vandenberg <jayvdb@gmail.com>
- Remove CFLAGS for noarch package
- Use setuptools to build the package
- Expand scope of fdupes to include egg-info
- Activate test suite, disabled using bcond check on platforms
  without test dependency pygame, and with test_buffer_api_basic
  disabled on platforms other than x86_64 and aarch64 due to
  failures caused by the installation of opengel-accelerate
- Change optional dependencies tk and numpy to Recommends
  instead of mandatory run time dependencies
- Add missing python-tk to Recommends to complement tk
- Change mtime adjustment algorithm to be more reflective of the
  source date, based on OpenGL/__init__.py instead of .changes
- Upgrade to 3.1.3b2
  - Python 3.7 compatibility fixes
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Thu Oct 25 2018 Tomáš Chvátal <tchvatal@suse.com>
- Update to 3.1.3b1:
  * no obvious changelog
* Mon Jun  5 2017 aloisio@gmx.com
- Update to version 3.1.1a1
- Added python-opengl.changes as source
- Converted to single-spec
* Mon Jul 14 2014 toddrme2178@gmail.com
- Update to 3.1.0
  * no changelog
* Fri Apr 19 2013 toddrme2178@gmail.com
- Update to 3.0.2
  * no changelog
- Add python 3 version
* Tue Sep 14 2010 coolo@novell.com
- update to 3.0.1
  * tons of changes, but no upstream documentation beside
    ChangeLog.txt
* Tue Aug 11 2009 matejcik@suse.cz
- removed non-applied patches
- switched to noarch (accelerator is not present, so no
  platform-dependent parts)
* Thu Aug  6 2009 matejcik@suse.cz
- update to 3.0.0
  * big under-the-hood rewrite while using backwards-compatible API
  * support for entire OGL3.0 api and most extensions
  * plug-in API
  * lower performance (accelerator module is not done yet)
  * package-level configuration flags
* Wed Jun 10 2009 ro@suse.de
- buildreq: replace gle by libgle-devel for >= 11.2
* Mon May  4 2009 ro@suse.de
- buildrequires: replace python-numeric by python-numpy
  for >= 11.2
* Fri Jan 26 2007 jmatejek@suse.cz
- removed strict-aliasing warnings
- removed invalid operations
* Tue Nov 21 2006 prusnak@suse.cz
- changes according to PEP353 (pep353.diff)
* Mon Sep 11 2006 jmatejek@suse.cz
- replaced a mistyped unicode nonbreakspace with a
  regular space, thus fixing build with python2.5
* Tue Feb 28 2006 jmatejek@suse.cz
- updated to reflect python changes due to #149809
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Jan 23 2006 jmatejek@suse.cz
- added build dependency on tk-devel
- fixed build not to require X server
* Mon Jun 20 2005 ltinkl@suse.cz
- added freeglut* packages to fix dependencies (#80605), plus
  optional (but recommended) dependency on python-imaging (pil)
* Tue Nov 23 2004 mcihar@suse.cz
- update to 2.0.1.09
- simplified filelist generating
* Wed Aug  4 2004 mcihar@suse.cz
- update to 2.0.1.08
* Wed Apr 21 2004 mcihar@suse.cz
- fix gcc warning
- fixed python requires
- use sed instead of patch for lib64
* Sat Jan 10 2004 adrian@suse.de
- build as user
* Mon Jun 16 2003 mcihar@suse.cz
- added some magic to generate correct filelist
* Mon Jun  9 2003 mcihar@suse.cz
- documentation isn't executable
* Thu Jun  5 2003 mcihar@suse.cz
- rather move documentation than symlink, as otherwise upgrade
  doesn't work correctly
* Tue May 27 2003 mcihar@suse.cz
- install documentation only once
* Fri Jan 10 2003 mcihar@suse.cz
- fixed build for lib64 arches
* Mon Jan  6 2003 mcihar@suse.cz
- initial package version
